@@ -853,7 +853,8 @@ module.exports = {
 		"9.4.0",
 		"9.4.1",
 		"9.4.2",
-		"9.4.3"
+		"9.4.3",
+		"9.4.4"
 	],
 	"84.0.4129.0": [
 		"10.0.0-beta.1",
@@ -1000,7 +1001,10 @@ module.exports = {
 		"10.2.0",
 		"10.3.0",
 		"10.3.1",
-		"10.3.2"
+		"10.3.2",
+		"10.4.0",
+		"10.4.1",
+		"10.4.2"
 	],
 	"86.0.4234.0": [
 		"11.0.0-beta.1",
@@ -1105,7 +1109,11 @@ module.exports = {
 		"11.2.0",
 		"11.2.1",
 		"11.2.2",
-		"11.2.3"
+		"11.2.3",
+		"11.3.0",
+		"11.4.0",
+		"11.4.1",
+		"11.4.2"
 	],
 	"89.0.4328.0": [
 		"12.0.0-beta.1",
@@ -1147,7 +1155,18 @@ module.exports = {
 		"12.0.0-beta.21",
 		"12.0.0-beta.22",
 		"12.0.0-beta.23",
-		"12.0.0-beta.24"
+		"12.0.0-beta.24",
+		"12.0.0-beta.25",
+		"12.0.0-beta.26"
+	],
+	"89.0.4389.23": [
+		"12.0.0-beta.27",
+		"12.0.0-beta.28",
+		"12.0.0-beta.29"
+	],
+	"89.0.4389.58": [
+		"12.0.0-beta.30",
+		"12.0.0-beta.31"
 	],
 	"87.0.4268.0": [
 		"12.0.0-nightly.20201013",
@@ -1171,6 +1190,57 @@ module.exports = {
 	"88.0.4324.0": [
 		"12.0.0-nightly.20201116"
 	],
+	"89.0.4389.69": [
+		"12.0.0"
+	],
+	"89.0.4389.82": [
+		"12.0.1"
+	],
+	"89.0.4389.90": [
+		"12.0.2"
+	],
+	"90.0.4402.0": [
+		"13.0.0-beta.2",
+		"13.0.0-beta.3",
+		"13.0.0-nightly.20210210",
+		"13.0.0-nightly.20210211",
+		"13.0.0-nightly.20210212",
+		"13.0.0-nightly.20210216",
+		"13.0.0-nightly.20210217",
+		"13.0.0-nightly.20210218",
+		"13.0.0-nightly.20210219",
+		"13.0.0-nightly.20210222",
+		"13.0.0-nightly.20210225",
+		"13.0.0-nightly.20210226",
+		"13.0.0-nightly.20210301",
+		"13.0.0-nightly.20210302",
+		"13.0.0-nightly.20210303",
+		"14.0.0-nightly.20210304"
+	],
+	"90.0.4415.0": [
+		"13.0.0-beta.4",
+		"13.0.0-beta.5",
+		"13.0.0-beta.6",
+		"13.0.0-beta.7",
+		"13.0.0-beta.8",
+		"13.0.0-beta.9",
+		"13.0.0-beta.11",
+		"14.0.0-nightly.20210305",
+		"14.0.0-nightly.20210308",
+		"14.0.0-nightly.20210309",
+		"14.0.0-nightly.20210311",
+		"14.0.0-nightly.20210315",
+		"14.0.0-nightly.20210316",
+		"14.0.0-nightly.20210317",
+		"14.0.0-nightly.20210318",
+		"14.0.0-nightly.20210319",
+		"14.0.0-nightly.20210323",
+		"14.0.0-nightly.20210324",
+		"14.0.0-nightly.20210325",
+		"14.0.0-nightly.20210326",
+		"14.0.0-nightly.20210329",
+		"14.0.0-nightly.20210330"
+	],
 	"89.0.4349.0": [
 		"13.0.0-nightly.20201215",
 		"13.0.0-nightly.20201216",
@@ -1201,7 +1271,10 @@ module.exports = {
 		"13.0.0-nightly.20210208",
 		"13.0.0-nightly.20210209"
 	],
-	"90.0.4402.0": [
-		"13.0.0-nightly.20210210"
+	"91.0.4448.0": [
+		"14.0.0-nightly.20210331",
+		"14.0.0-nightly.20210401",
+		"14.0.0-nightly.20210402",
+		"14.0.0-nightly.20210406"
 	]
 };
\ No newline at end of file
